@@ -36,12 +36,13 @@ namespace Akonadi {
  */
 class AKONADIPRIVATE_EXPORT AkAppend : public Handler
 {
+  Q_OBJECT
 public:
     AkAppend();
 
     ~AkAppend();
 
-    bool handleLine(const QByteArray& line);
+    bool parseStream();
 
 protected:
     bool commit();
