@@ -18,28 +18,40 @@
  ***************************************************************************/
 #include "login.h"
 
+#include <QtCore/QDebug>
+
 #include "response.h"
-#include "connection.h"
+#include "akonadiconnection.h"
 #include "imapstreamparser.h"
 
-using namespace Akonadi::Server;
+using namespace Akonadi;
 
 Login::Login(): Handler()
 {
 }
 
+
+Login::~Login()
+{
+}
+
+
 bool Login::parseStream()
 {
-  const QByteArray sessionId = m_streamParser->readString();
-  if ( sessionId.isEmpty() ) {
+  QByteArray sessionId = m_streamParser->readString();
+  if ( sessionId.isEmpty() )
     return failureResponse( "Missing session identifier." );
-  }
   connection()->setSessionId( sessionId );
 
-  // ignore anything that follows, for Roundcube compatibility
-  m_streamParser->readUntilCommandEnd();
+  Response response;
+  response.setTag( tag() );
+  response.setSuccess();
+  response.setString( "User logged in" );
 
-  successResponse( "User logged in" );
-  Q_EMIT connectionStateChange( Authenticated );
+  emit responseAvailable( response );
+  emit connectionStateChange( Authenticated );
+  deleteLater();
   return true;
 }
+
+#include "login.moc"
