@@ -88,7 +88,8 @@ QueryBuilder::QueryBuilder( QueryType type ) :
 
 void QueryBuilder::addTable(const QString & table)
 {
-  mTables << table;
+  if ( !mTables.contains( table ) )
+    mTables << table;
 }
 
 void QueryBuilder::addValueCondition(const QString & column, Query::CompareOperator op, const QVariant & value)
@@ -169,8 +170,13 @@ bool QueryBuilder::exec()
 
 #ifndef QUERYBUILDER_UNITTEST
   mQuery.prepare( statement );
+  //too heavy debug info but worths to have from time to time
+//   qDebug() << "Executing query" << statement;
   for ( int i = 0; i < mBindValues.count(); ++i )
+  {
     mQuery.bindValue( QString::fromLatin1( ":%1" ).arg( i ), mBindValues[i] );
+//     qDebug() << QString::fromLatin1( ":%1" ).arg( i ) <<  mBindValues[i];
+  }
   if ( !mQuery.exec() ) {
     qDebug() << "Error during executing query" << statement << ": " << mQuery.lastError().text();
     return false;
